@@ -3,14 +3,11 @@ try:
     from collections import Counter
 except ImportError:
     from .compat import Counter
-import datetime
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.timezone import now
 from parler.managers import TranslationManager
 
-from .settings import BLOG_TAGCLOUD_MIN, BLOG_TAGCLOUD_MAX
-
 
 class TaggedFilterItem(object):
 
@@ -20,7 +17,7 @@ class TaggedFilterItem(object):
         o con gli stessi tag di un model o un queryset
         """
         tags = self._taglist(other_model, queryset)
-        return self.get_query_set().filter(taglist__in=tags)
+        return self.get_queryset().filter(taglist__in=tags)
 
     def _taglist(self, other_model=None, queryset=None):
         """
@@ -51,7 +48,7 @@ class TaggedFilterItem(object):
 
     def tag_list_slug(self, other_model=None, queryset=None):
         queryset = self.tag_list(other_model, queryset)
-        return queryset.values("slug")
+        return queryset.values('slug')
 
     def tag_cloud(self, other_model=None, queryset=None, published=True):
         from taggit.models import TaggedItem
@@ -73,57 +70,64 @@ class TaggedFilterItem(object):
 
 class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
     use_for_related_fields = True
-    start_date_field = "date_published"
-    end_date_field = "date_published_end"
-    publish_field = "publish"
+    start_date_field = 'date_published'
+    end_date_field = 'date_published_end'
+    publish_field = 'publish'
+
+    def get_queryset(self, *args, **kwargs):
+        try:
+            return super(GenericDateTaggedManager, self).get_queryset(*args, **kwargs)
+        except AttributeError:
+            return super(GenericDateTaggedManager, self).get_query_set(*args, **kwargs)
 
     def published(self, queryset=None):
         queryset = self.published_future(queryset)
         if self.start_date_field:
             return queryset.filter(
-                **{"%s__lte" % self.start_date_field: datetime.datetime.now()})
+                **{'%s__lte' % self.start_date_field: now()})
         else:
             return queryset
 
     def published_future(self, queryset=None):
         if queryset is None:
-            queryset = self.get_query_set().all()
+            queryset = self.get_queryset().all()
         if self.end_date_field:
             qfilter = (
-                models.Q(**{"%s__gte" % self.end_date_field: datetime.datetime.now()})
-                | models.Q(**{"%s__isnull" % self.end_date_field: True})
+                models.Q(**{'%s__gte' % self.end_date_field: now()})
+                | models.Q(**{'%s__isnull' % self.end_date_field: True})
             )
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
 
     def archived(self, queryset=None):
         if queryset is None:
-            queryset = self.get_query_set().all()
+            queryset = self.get_queryset().all()
         if self.end_date_field:
             qfilter = (
-                models.Q(**{"%s__lte" % self.end_date_field: datetime.datetime.now()})
-                | models.Q(**{"%s__isnull" % self.end_date_field: False})
+                models.Q(**{'%s__lte' % self.end_date_field: now()})
+                | models.Q(**{'%s__isnull' % self.end_date_field: False})
             )
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
 
     def available(self, queryset=None):
         if queryset is None:
-            queryset = self.get_query_set().all()
+            queryset = self.get_queryset().all()
         return queryset.filter(**{self.publish_field: True})
 
     def filter_by_language(self, language):
-        queryset = self.get_query_set()
-        return queryset.filter(models.Q(language__isnull=True) | models.Q(language=language))
+        return self.get_queryset().active_translations(language_code=language)
 
     def get_months(self, queryset=None):
-        """Get months with aggregatet count (how much posts is in the month). Results are ordered by date."""
+        """
+        Get months with aggregate count (how much posts is in the month). Results are ordered by date.
+        """
         if queryset is None:
-            queryset = self.get_query_set()
+            queryset = self.get_queryset()
         dates = queryset.values_list(self.start_date_field, flat=True)
         dates = [(x.year, x.month) for x in dates]
         date_counter = Counter(dates)
         dates = set(dates)
         dates = sorted(dates, reverse=True)
-        return [{'date': datetime.date(year=year, month=month, day=1),
+        return [{'date': now().replace(year=year, month=month, day=1),
                  'count': date_counter[year, month]} for year, month in dates]
